@@ -1,5 +1,4 @@
-from python_helper.api.src.domain import Constant as c
-from python_helper.api.src.service import StringHelper, LogHelper, ReflectionHelper, EnvironmentHelper
+from python_helper.api.src.service import LogHelper, ReflectionHelper, EnvironmentHelper
 
 def EnvironmentVariable(*outerArgs, environmentVariables=None, **outerKwargs) :
     def innerMethodWrapper(resourceInstanceMethod,*innerMethodArgs,**innerMethodKwargs) :
@@ -8,16 +7,18 @@ def EnvironmentVariable(*outerArgs, environmentVariables=None, **outerKwargs) :
             if environmentVariables :
                 for key,value in environmentVariables.items() :
                     originalEnvironmentVariables[key] = EnvironmentHelper.replaceEnvironmentVariable(key, value)
-            LogHelper.loadSettings() 
+            LogHelper.loadSettings()
             try :
                 methodReturn = resourceInstanceMethod(*innerArgs,**innerKwargs)
             except Exception as exception :
+                resetEnvironmentVariables(environmentVariables, originalEnvironmentVariables)
                 raise exception
-            if environmentVariables :
-                for key in environmentVariables.keys() :
-                    if key in originalEnvironmentVariables :
-                        EnvironmentHelper.setEnvironmentValue(key, originalEnvironmentVariables[key])
+            resetEnvironmentVariables(environmentVariables, originalEnvironmentVariables)
             return methodReturn
         ReflectionHelper.overrideSignatures(innerResourceInstanceMethod, resourceInstanceMethod)
         return innerResourceInstanceMethod
     return innerMethodWrapper
+
+def resetEnvironmentVariables(environmentVariables, originalEnvironmentVariables) :
+    EnvironmentHelper.resetEnvironmentVariables(environmentVariables, originalEnvironmentVariables)
+    LogHelper.loadSettings()
